%define anolis_release 2

%global __requires_exclude %{?__requires_exclude:%{__requires_exclude}|}^perl\\(Math::BigInt\\)$
%global __requires_exclude %{__requires_exclude}|^perl\\(Math::BigRat\\)$
%global __requires_exclude %{__requires_exclude}|^perl\\(Carp\\)$

Name:           perl-bignum
Version:        0.66
Release:        %{anolis_release}%{?dist}
Summary:        Transparent big number support for Perl
License:        GPL+ or Artistic
URL:            https://metacpan.org/release/bignum
Source0:        https://cpan.metacpan.org/authors/id/P/PJ/PJACKLAM/bignum-%{version}.tar.gz
BuildRequires:  make
BuildRequires:  coreutils
BuildRequires:  perl(Config)
BuildRequires:  perl(strict)
BuildRequires:  perl(warnings)
BuildRequires:  perl(constant)
BuildRequires:  perl(Exporter)
BuildRequires:  perl(overload)
BuildRequires:  perl-generators
BuildRequires:  perl-interpreter
BuildRequires:  perl(Carp) >= 1.22
BuildRequires:  perl(Math::BigFloat)
BuildRequires:  perl(:VERSION) >= 5.10
BuildRequires:  perl(Math::BigInt::GMP)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Math::BigRat) >= 0.2621
BuildRequires:  perl(Math::BigInt) >= 1.999830
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.76
Requires:       perl(Carp) >= 1.22
Requires:       perl(Math::BigRat) >= 0.2621
Requires:       perl(Math::BigInt) >= 1.999830
Conflicts:      perl < 4:5.22.0

BuildArch:      noarch
%description
Perl-Bignum is a Perl module that allows you to work with numbers of
arbitrary precision. This means that you can perform calculations with
numbers that exceed the range of standard numeric data types like
integers or floating-point numbers in Perl. Perl-Bignum uses the
Math::BigInt library to create and manipulate numbers of arbitrary size.

Working with arbitrary-precision numbers can be useful in a variety of
situations, such as cryptography or scientific computing. Perl-Bignum
provides a convenient way to handle these types of calculations in Perl
without resorting to external libraries or custom code.

To use Perl-Bignum, you need to first import the module using the "use"
keyword. Once you've done that, you can create an arbitrary-precision
number using the "new" function provided by Math::BigInt. From there,
you can perform arithmetic operations like addition, subtraction,
multiplication, and division on these numbers using the functions
provided by Perl-Bignum.

In addition to basic arithmetic operations, Perl-Bignum also provides
functions for advanced mathematical operations like exponentiation,
logarithms, and factorials. It can also perform bitwise operations on
arbitrary-precision numbers.

One important feature of Perl-Bignum is that it seamlessly integrates
with Perl's built-in operators and functions. This means that you can
use Perl-Bignum in your code without having to make any significant
changes to your existing codebase.

Overall, Perl-Bignum provides a convenient way to work with numbers
of arbitrary precision in Perl. It is a powerful and versatile tool
that can help you perform complex numerical calculations with ease.

%package tests
Summary:        Tests for perl-bignum
Requires:       perl-bignum = %{?epoch:%{epoch}:}%{version}-%{release}
Requires:       perl-Test-Harness

%description tests
Tests from perl-bignum. Execute them
with "%{_libexecdir}/perl-bignum/test".

%package doc
Summary:        Documentation files for perl-bignum
Requires:       perl-bignum = %{EVR}
BuildArch:      noarch

%description    doc
The perl-bignum-doc package contains documentation files for perl-bignum.

%prep
%autosetup -n bignum-%{version}

# Correct shebangs and permission
for F in lib/Math/BigInt/Trace.pm lib/Math/BigFloat/Trace.pm; do
    perl -MConfig -pi -e 's{\A#!.*perl\b}{$Config{startperl}}' "$F"
    chmod -x "$F"
done

# Help generators to recognize Perl scripts
for F in t/*.t; do
    perl -i -MConfig -ple 'print $Config{startperl} if $. == 1 && !s{\A#!.*perl\b}{$Config{startperl}}' "$F"
    chmod +x "$F"
done

%build
perl Makefile.PL INSTALLDIRS=vendor NO_PACKLIST=1 NO_PERLLOCAL=1
%{make_build}

%install
%{make_install}
%{_fixperms} %{buildroot}/*

# Install tests
mkdir -p %{buildroot}%{_libexecdir}/perl-bignum
cp -a t %{buildroot}%{_libexecdir}/perl-bignum
rm %{buildroot}%{_libexecdir}/perl-bignum/t/00sig.t
cat > %{buildroot}%{_libexecdir}/perl-bignum/test << 'EOF'
#!/usr/bin/sh
cd %{_libexecdir}/perl-bignum && exec prove -I . -j "$(getconf _NPROCESSORS_ONLN)"
EOF
chmod +x %{buildroot}%{_libexecdir}/perl-bignum/test

%check
unset TEST_SIGNATURE
export HARNESS_OPTIONS=j$(perl -e 'if ($ARGV[0] =~ /.*-j([0-9][0-9]*).*/) {print $1} else {print 1}' -- '%{?_smp_mflags}')
make test

%files
%license LICENSE
%{perl_vendorlib}/*
%{_mandir}/man3/*

%files doc
%doc BUGS CHANGES README TODO

%files tests
%{_libexecdir}/perl-bignum

%changelog
* Tue Apr 11 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 0.66-2
- Update some description

* Fri Feb 10 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.66-1
- update to version 0.66

* Fri Feb 03 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.65-3
- remove versioned MODULE_COMPAT_ requires

* Mon Jan 30 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 0.65-2
- rebuild with perl 5.36.0

* Wed Apr 20 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 0.65-1
- init from upstream
